@@ -3,14 +3,16 @@
 from iprofile import texts
 from iprofile.cli.shell import Shell
 from iprofile.core.decorators import icommand
-from iprofile.models import ICommand
+from iprofile.core.models import ICommand
 import click
 import os
 import sys
+import traceback
+import six
 
 
 @icommand(help=texts.HELP_DJANGO, short_help=texts.HELP_DJANGO)
-@click.argument('name', required=False)
+@click.argument('profile', required=False)
 @click.argument('ipython_options', nargs=-1, required=False)
 @click.option('--settings', required=False, help=texts.HELP_SETTINGS)
 class Django(ICommand):
@@ -20,10 +22,10 @@ class Django(ICommand):
 
         settings = (
             options.get('settings') or
-            self.global_config.get('django_settings_module')
+            self.settings.get('django')
         )
 
-        if not settings:
+        if not (settings and isinstance(settings, six.string_types)):
             self.red(texts.ERROR_DJANGO_WITHOUT_SETTINGS)
             return
 
@@ -31,8 +33,9 @@ class Django(ICommand):
         sys.path.append(os.getcwd())
         try:
             django.setup()
-        except ImportError:
+        except Exception:
             self.red(texts.ERROR_DJANGO_INVALID_SETTINGS.format(settings))
+            traceback.print_exc()
             return
 
         Shell.run(options)
